package net.lamgc.scext.onedrive_transfer.remote.request

import java.util.*

/**
 * 从节点发送任务分配请求.
 *
 * 主节点将根据请求的 acceptMaxSize 进行预分配任务.
 *
 * @property acceptMaxSize 从节点可接受的最大文件大小.
 */
data class TaskAllocationRequest(
    val acceptMaxSize: Long
)

/**
 * 主节点返回的任务分配结果.
 *
 * @property allocated 是否成功分配了任务.
 * @property info 预分配的任务信息.
 */
data class TaskAllocationResponse(
    val allocated: Boolean,
    val info: TaskAllocationInfo? = null
)

/**
 * 任务分配信息.
 *
 * 主节点将为从节点保留任务一段时间, 直至从节点接受任务, 或者预分配任务超时.
 *
 * @property taskId 任务 ID.
 * @property ownerBotToken 任务所属的 Bot Token.
 * @property fileId 文件 ID.
 * @property fileSize 文件大小.
 */
data class TaskAllocationInfo(
    val taskId: UUID,
    val ownerBotToken: String,
    val fileId: String,
    val fileSize: Long,
)
